<?php

namespace jrosset;

/**
 * Class for “missing” mbstring functions
 */
final class MbstringExtended {
    /**
     * Multi-bytes implementation for {@see https://www.php.net/manual/function.str-pad.php str_pad}
     *
     * @param string      $string     The input string
     * @param int         $length     The minimum string length
     * @param string      $pad_string The padding string
     * @param int         $pad_type   STR_PAD_RIGHT, STR_PAD_LEFT, or STR_PAD_BOTH
     * @param string|null $encoding   The character encoding or the internal character encoding value is Null
     *
     * @return string The padded string
     */
    public static function str_pad (string $string, int $length, string $pad_string = ' ', int $pad_type = STR_PAD_RIGHT, string $encoding = null): string {
        $diff = strlen($string) - ($encoding === null ? mb_strlen($string) : mb_strlen($string, $encoding));
        return str_pad($string, $length + $diff, $pad_string, $pad_type);
    }
}